package com.theflyy.flyy_flutter_plugin;

import android.content.Context;
import android.content.Intent;
import android.util.Log;

import androidx.annotation.NonNull;

import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import theflyy.com.flyy.Flyy;
import theflyy.com.flyy.helpers.OnFlyyTaskComplete;

/**
 * FlyyFlutterPlugin
 */
public class FlyyFlutterPlugin implements FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private Context context;

    private final String FLYY_INIT = "flyy_init";
    private final String FLYY_SET_NEW_USER = "flyy_set_new_user";
    private final String FLYY_SET_USER = "flyy_set_user";
    private final String FLYY_SET_USER_NAME = "flyy_set_user_name";
    private final String FLYY_SEND_EVENT = "flyy_send_event";
    private final String FLYY_SEND_EVENT_JSON = "flyy_send_event_json";
    private final String FLYY_OPEN_OFFERS_SCREEN = "flyy_open_offers_screen";
    private final String FLYY_OPEN_REWARDS_SCREEN = "flyy_open_rewards_screen";
    private final String FLYY_OPEN_WALLET_SCREEN = "flyy_open_wallet_screen";
    private final String FLYY_OPEN_GIFT_CARDS_SCREEN = "flyy_gift_cards_screen";
    private final String FLYY_OPEN_REFERRAL_SCREEN = "flyy_open_referral_screen";


    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        context = flutterPluginBinding.getApplicationContext();
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "flyy_flutter_plugin");
        channel.setMethodCallHandler(this);
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull final Result result) {
        switch (call.method) {
            case FLYY_INIT:
                Flyy.init(context, String.valueOf(call.argument("partner-token")), Flyy.PRODUCTION);
                break;
            case FLYY_SET_NEW_USER:
                Flyy.setNewUser(String.valueOf(call.argument("ext-uid")), new OnFlyyTaskComplete() {
                    @Override
                    public void onComplete() {
                        result.success("success");
                    }
                });
                break;
            case FLYY_SET_USER:
                Flyy.setUser(String.valueOf(call.argument("ext-uid")), new OnFlyyTaskComplete() {
                    @Override
                    public void onComplete() {
                        result.success("success");
                    }
                });
                break;
            case FLYY_SET_USER_NAME:
                Flyy.setUsername(String.valueOf(call.argument("user-name")), new OnFlyyTaskComplete() {
                    @Override
                    public void onComplete() {
                        result.success("success");
                    }
                });
                break;
            case FLYY_SEND_EVENT:
                Flyy.sendEvent(String.valueOf(call.argument("key")),
                        String.valueOf(call.argument("value")),
                        new OnFlyyTaskComplete() {
                    @Override
                    public void onComplete() {
                        result.success("success");
                    }
                });
                break;
            case FLYY_SEND_EVENT_JSON:
                Map<String, String> hashMap = call.argument("json_value");

                Flyy.sendEvent(String.valueOf(call.argument("key")),
                        new JSONObject(hashMap),
                        new OnFlyyTaskComplete() {
                            @Override
                            public void onComplete() {
                                result.success("success");
                            }
                        });
                break;
            case FLYY_OPEN_OFFERS_SCREEN:
                openFlyyRouteActivity(FlyyRouteActivity.FLYY_OFFERS_PAGE);
                break;
            case FLYY_OPEN_REWARDS_SCREEN:
                openFlyyRouteActivity(FlyyRouteActivity.FLYY_REWARDS_PAGE);
                break;
            case FLYY_OPEN_WALLET_SCREEN:
                openFlyyRouteActivity(FlyyRouteActivity.FLYY_WALLET_PAGE);
                break;
            case FLYY_OPEN_GIFT_CARDS_SCREEN:
                openFlyyRouteActivity(FlyyRouteActivity.FLYY_GIFT_CARDS_PAGE);
                break;
            case FLYY_OPEN_REFERRAL_SCREEN:
                openFlyyRouteActivity(FlyyRouteActivity.FLYY_REFERRAL_HISTORY_PAGE);
                break;
            default:
                result.notImplemented();
                break;
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    private void openFlyyRouteActivity(String pageToOpen) {
        Intent startOffersActivity = new Intent(context, FlyyRouteActivity.class);
        startOffersActivity.putExtra(FlyyRouteActivity.PAGE_TO_OPEN, pageToOpen);
        startOffersActivity.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
        context.startActivity(startOffersActivity);
    }
}
