import 'dart:async';

import 'package:flutter/services.dart';

class FlyyFlutterPlugin {
  /*method names to invoke call from native android*/
  static const int STAGE = 0;
  static const int PRODUCTION = 1;

  static const String FLYY_INIT = "flyy_init";
  static const String FLYY_SET_NEW_USER = "flyy_set_new_user";
  static const String FLYY_SET_USER = "flyy_set_user";
  static const String FLYY_OPEN_OFFERS_SCREEN = "flyy_open_offers_screen";
  static const String FLYY_OPEN_REWARDS_SCREEN = "flyy_open_rewards_screen";
  static const String FLYY_OPEN_WALLET_SCREEN = "flyy_open_wallet_screen";
  static const String FLYY_OPEN_GIFT_CARDS_SCREEN = "flyy_gift_cards_screen";
  static const String FLYY_OPEN_REFERRAL_SCREEN = "flyy_open_referral_screen";
  static const String FLYY_SET_USER_NAME = "flyy_set_user_name";
  static const String FLYY_SEND_EVENT = "flyy_send_event";
  static const String FLYY_SEND_EVENT_JSON = "flyy_send_event_json";

  static const MethodChannel _channel =
      const MethodChannel('flyy_flutter_plugin');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static void initFlyySDK(String partnerToken, int environment) {
    _channel.invokeMethod(FLYY_INIT, {"partner-token": partnerToken, "environment": environment});
  }

  static Future<String> setFlyyNewUser(String externalUserId) async {
    final String result = await _channel.invokeMethod(FLYY_SET_NEW_USER, {"ext-uid": externalUserId});
    return result;
  }

  static Future<String> setFlyyUser(String externalUserId) async {
    final String result = await  _channel.invokeMethod(FLYY_SET_USER, {"ext-uid": externalUserId});
    return result;
  }

  static Future<String> setFlyyUserName(String userName) async {
    final String result = await _channel.invokeMethod(FLYY_SET_USER_NAME, {"user-name": userName});
    return result;
  }

  static Future<String> sendEvent(String key, String value) async {
    final String result = await _channel.invokeMethod(FLYY_SEND_EVENT, {"key": key, "value": value});
    return result;
  }

  static Future<String> sendJSONEvent(String key, Map<String, String> jsonData) async {
    final String result = await _channel.invokeMethod(FLYY_SEND_EVENT_JSON, {"key": key, "json_value": jsonData});
    return result;
  }

  static void openFlyyOffersPage() {
    _channel.invokeMethod(FLYY_OPEN_OFFERS_SCREEN);
  }

  static void openFlyyRewardsPage() {
    _channel.invokeMethod(FLYY_OPEN_REWARDS_SCREEN);
  }

  static void openFlyyWalletPage() {
    _channel.invokeMethod(FLYY_OPEN_WALLET_SCREEN);
  }

  static void openFlyyGiftCardsPage() {
    _channel.invokeMethod(FLYY_OPEN_GIFT_CARDS_SCREEN);
  }

  static void openFlyyReferralsPage() {
    _channel.invokeMethod(FLYY_OPEN_REFERRAL_SCREEN);
  }
}
